# from ._utils import _NoneType

# area = _NoneType()
# blend_data = _NoneType()
# collection = _NoneType()
# engine = _NoneType()
# gizmo_group = _NoneType()
# layer_collection = _NoneType()
# mode = _NoneType()
# preferences = _NoneType()
# region = _NoneType()
# region_data = _NoneType()
# scene = _NoneType()
# screen = _NoneType()
# space_data = _NoneType()
# tool_settings = _NoneType()
# view_layer = _NoneType()
# window = _NoneType()
# window_manager = _NoneType()
# workspace = _NoneType()
# scene = _NoneType()
# view_layer = _NoneType()
# visible_objects = _NoneType()
# selectable_objects = _NoneType()
# selected_objects = _NoneType()
# editable_objects = _NoneType()
# selected_editable_objects = _NoneType()
# objects_in_mode = _NoneType()
# objects_in_mode_unique_data = _NoneType()
# visible_bones = _NoneType()
# editable_bones = _NoneType()
# selected_bones = _NoneType()
# selected_editable_bones = _NoneType()
# visible_pose_bones = _NoneType()
# selected_pose_bones = _NoneType()
# selected_pose_bones_from_active_object = _NoneType()
# active_bone = _NoneType()
# active_pose_bone = _NoneType()
# active_object = _NoneType()
# object = _NoneType()
# edit_object = _NoneType()
# sculpt_object = _NoneType()
# vertex_paint_object = _NoneType()
# weight_paint_object = _NoneType()
# image_paint_object = _NoneType()
# particle_edit_object = _NoneType()
# pose_object = _NoneType()
# sequences = _NoneType()
# selected_sequences = _NoneType()
# selected_editable_sequences = _NoneType()
# selected_nla_strips = _NoneType()
# gpencil_data = _NoneType()
# gpencil_data_owner = _NoneType()
# annotation_data = _NoneType()
# annotation_data_owner = _NoneType()
# visible_gpencil_layers = _NoneType()
# editable_gpencil_layers = _NoneType()
# editable_gpencil_strokes = _NoneType()
# active_gpencil_layer = _NoneType()
# active_gpencil_frame = _NoneType()
# active_annotation_layer = _NoneType()
# active_operator = _NoneType()
# visible_fcurves = _NoneType()
# editable_fcurves = _NoneType()
# selected_visible_fcurves = _NoneType()
# selected_editable_fcurves = _NoneType()
# active_editable_fcurve = _NoneType()
# selected_editable_keyframes = _NoneType()
# active_base = _NoneType()
# active_object = _NoneType()
# texture_slot = _NoneType()
# scene = _NoneType()
# world = _NoneType()
# object = _NoneType()
# mesh = _NoneType()
# armature = _NoneType()
# lattice = _NoneType()
# curve = _NoneType()
# meta_ball = _NoneType()
# light = _NoneType()
# speaker = _NoneType()
# lightprobe = _NoneType()
# camera = _NoneType()
# material = _NoneType()
# material_slot = _NoneType()
# texture = _NoneType()
# texture_user = _NoneType()
# texture_user_property = _NoneType()
# bone = _NoneType()
# edit_bone = _NoneType()
# pose_bone = _NoneType()
# particle_system = _NoneType()
# particle_system_editable = _NoneType()
# particle_settings = _NoneType()
# cloth = _NoneType()
# soft_body = _NoneType()
# fluid = _NoneType()
# collision = _NoneType()
# brush = _NoneType()
# dynamic_paint = _NoneType()
# line_style = _NoneType()
# collection = _NoneType()
# gpencil = _NoneType()
# volume = _NoneType()
# edit_image = _NoneType()
# edit_mask = _NoneType()
# selected_nodes = _NoneType()
# active_node = _NoneType()
# light = _NoneType()
# material = _NoneType()
# world = _NoneType()
# edit_text = _NoneType()
# edit_movieclip = _NoneType()
# edit_mask = _NoneType()
# edit_mask = _NoneType()



class _NoneType:
    def __call__(self, *args, **kwargs):
        return _NoneType()
    def __getattr__(self, *args, **kwargs):
        return _NoneType()
    def __lt__(self, *args, **kwargs):
        return _NoneType()
    def __le__(self, *args, **kwargs):
        return _NoneType()
    def __eq__(self, *args, **kwargs):
        return _NoneType()
    def __ne__(self, *args, **kwargs):
        return _NoneType()
    def __gt__(self, *args, **kwargs):
        return _NoneType()
    def __ge__(self, *args, **kwargs):
        return _NoneType()
    def __repr__(self, *args, **kwargs):
        return "This is a fake object. Actual bpy cannot be used outside of blender"
    def __str__(self, *args, **kwargs):
        return "This is a fake object. Actual bpy cannot be used outside of blender"
    def __bytes__(self, *args, **kwargs):
        return b"This is a fake object. Actual bpy cannot be used outside of blender"
    def __format__(self, *args, **kwargs):
        return _NoneType()
    def __hash__(self, *args, **kwargs):
        return hash("This is a fake object. Actual bpy cannot be used outside of blender")
    def __bool__(self, *args, **kwargs):
        return True
    def __len__(self, *args, **kwargs):
        return 0
    def __iter__(self, *args, **kwargs):
        return _NoneType()
    def __reversed__(self, *args, **kwargs):
        return _NoneType()
    def __add__(self, *args, **kwargs):
        return _NoneType()
    def __sub__(self, *args, **kwargs):
        return _NoneType()
    def __mul__(self, *args, **kwargs):
        return _NoneType()
    def __matmul__(self, *args, **kwargs):
        return _NoneType()
    def __truediv__(self, *args, **kwargs):
        return _NoneType()
    def __floordiv__(self, *args, **kwargs):
        return _NoneType()
    def __mod__(self, *args, **kwargs):
        return _NoneType()
    def __divmod__(self, *args, **kwargs):
        return _NoneType()
    def __pow__(self, *args, **kwargs):
        return _NoneType()
    def __lshift__(self, *args, **kwargs):
        return _NoneType()
    def __rshift__(self, *args, **kwargs):
        return _NoneType()
    def __and__(self, *args, **kwargs):
        return _NoneType()
    def __xor__(self, *args, **kwargs):
        return _NoneType()
    def __or__(self, *args, **kwargs):
        return _NoneType()
    def __radd__(self, *args, **kwargs):
        return _NoneType()
    def __rsub__(self, *args, **kwargs):
        return _NoneType()
    def __rmul__(self, *args, **kwargs):
        return _NoneType()
    def __rmatmul__(self, *args, **kwargs):
        return _NoneType()
    def __rtruediv__(self, *args, **kwargs):
        return _NoneType()
    def __rfloordiv__(self, *args, **kwargs):
        return _NoneType()
    def __rmod__(self, *args, **kwargs):
        return _NoneType()
    def __rdivmod__(self, *args, **kwargs):
        return _NoneType()
    def __rpow__(self, *args, **kwargs):
        return _NoneType()
    def __rlshift__(self, *args, **kwargs):
        return _NoneType()
    def __rrshift__(self, *args, **kwargs):
        return _NoneType()
    def __rand__(self, *args, **kwargs):
        return _NoneType()
    def __rxor__(self, *args, **kwargs):
        return _NoneType()
    def __ror__(self, *args, **kwargs):
        return _NoneType()
    def __iadd__(self, *args, **kwargs):
        return _NoneType()
    def __isub__(self, *args, **kwargs):
        return _NoneType()
    def __imul__(self, *args, **kwargs):
        return _NoneType()
    def __imatmul__(self, *args, **kwargs):
        return _NoneType()
    def __itruediv__(self, *args, **kwargs):
        return _NoneType()
    def __ifloordiv__(self, *args, **kwargs):
        return _NoneType()
    def __imod__(self, *args, **kwargs):
        return _NoneType()
    def __ipow__(self, *args, **kwargs):
        return _NoneType()
    def __ilshift__(self, *args, **kwargs):
        return _NoneType()
    def __irshift__(self, *args, **kwargs):
        return _NoneType()
    def __iand__(self, *args, **kwargs):
        return _NoneType()
    def __ixor__(self, *args, **kwargs):
        return _NoneType()
    def __ior__(self, *args, **kwargs):
        return _NoneType()
    def __neg__(self, *args, **kwargs):
        return _NoneType()
    def __pos__(self, *args, **kwargs):
        return _NoneType()
    def __abs__(self, *args, **kwargs):
        return _NoneType()
    def __invert__(self, *args, **kwargs):
        return _NoneType()
    def __complex__(self, *args, **kwargs):
        return _NoneType()
    def __int__(self, *args, **kwargs):
        return _NoneType()
    def __float__(self, *args, **kwargs):
        return _NoneType()
    def __index__(self, *args, **kwargs):
        return _NoneType()
    def __round__(self, *args, **kwargs):
        return _NoneType()
    def __trunc__(self, *args, **kwargs):
        return _NoneType()
    def __floor__(self, *args, **kwargs):
        return _NoneType()
    def __ceil__(self, *args, **kwargs):
        return _NoneType()



from ._utils import _NoneType
context = _NoneType()
data = _NoneType()
msgbus = _NoneType()
ops = _NoneType()
types = _NoneType()
utils = _NoneType()
path = _NoneType()
app = _NoneType()
props = _NoneType()
# from . import context
# from . import data
# from . import msgbus
# from . import ops
# from . import types
# from . import utils
# from . import path
# from . import app
# from . import props